Struct slab_typesafe::VacantEntry [] [src]

pub struct VacantEntry<'a, K: Into<usize> + From<usize>, V: 'a> { /* fields omitted */ }

A handle to an vacant entry in a Slab.

VacantEntry allows constructing values with the key that they will be assigned to.

Examples

#[macro_use] extern crate slab_typesafe;
declare_slab_token!(MyIndex);
let mut slab : Slab<MyIndex, _> = Slab::new();

let hello = {
    let entry = slab.vacant_entry();
    let key = entry.key();

    entry.insert((key, "hello"));
    key
};

assert_eq!(hello, slab[hello].0);
assert_eq!("hello", slab[hello].1);

Methods

impl<'a, K: Into<usize> + From<usize>, V: 'a> VacantEntry<'a, K, V>
[src]

[src]

Insert a value in the entry, returning a mutable reference to the value.

To get the key associated with the value, use key prior to calling insert.

Examples

#[macro_use] extern crate slab_typesafe;
declare_slab_token!(MyIndex);
let mut slab : Slab<MyIndex, _> = Slab::new();

let hello = {
    let entry = slab.vacant_entry();
    let key : MyIndex = entry.key();

    entry.insert((key, "hello"));
    key
};

assert_eq!(hello, slab[hello].0);
assert_eq!("hello", slab[hello].1);

[src]

Return the key associated with this entry.

A value stored in this entry will be associated with this key.

Examples

#[macro_use] extern crate slab_typesafe;
declare_slab_token!(MyIndex);
let mut slab : Slab <MyIndex, _> = Slab::new();

let hello = {
    let entry = slab.vacant_entry();
    let key : MyIndex = entry.key();

    entry.insert((key, "hello"));
    key
};

assert_eq!(hello, slab[hello].0);
assert_eq!("hello", slab[hello].1);